---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2003-07-11;170
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20030712&codiceRedaz=003G0200&dataVigenza=20251104
dataGU: 20030712
codiceRedaz: 003G0200
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 9 maggio 2003, n. 105, recante disposizioni urgenti per le universita' e gli enti di ricerca.

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 9 maggio 2003, n. 105, recante disposizioni urgenti per le universita' e gli enti di ricerca, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

